// Copyright 2020 The TensorStore Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "tensorstore/internal/oauth2/fixed_token_auth_provider.h"

#include <gtest/gtest.h>
#include "absl/time/clock.h"
#include "tensorstore/util/result.h"

namespace {

using ::tensorstore::internal_oauth2::FixedTokenAuthProvider;

TEST(FixedTokenAuthProvider, Minimal) {
  FixedTokenAuthProvider auth("token");

  auto result = auth.GetToken();
  EXPECT_TRUE(result.ok());

  EXPECT_EQ("token", result->token);
  EXPECT_LT(absl::Now(), result->expiration);
}

}  // namespace
